# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateVolumeMirror(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'remote_pool': 'str',
        'dedupe': 'str',
        'compress': 'str',
        'policy': 'str',
        'new_cg_name': 'str',
        'wan_optimization': 'bool'
    }

    attribute_map = {
        'display_name': 'display_name',
        'remote_pool': 'remote_pool',
        'dedupe': 'dedupe',
        'compress': 'compress',
        'policy': 'policy',
        'new_cg_name': 'new_cg_name',
        'wan_optimization': 'wan_optimization'
    }

    def __init__(self, display_name=None, remote_pool=None, dedupe=None, compress=None, policy=None, new_cg_name=None, wan_optimization=None, _configuration=None):  # noqa: E501
        """CreateVolumeMirror - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._remote_pool = None
        self._dedupe = None
        self._compress = None
        self._policy = None
        self._new_cg_name = None
        self._wan_optimization = None
        self.discriminator = None

        self.display_name = display_name
        self.remote_pool = remote_pool
        if dedupe is not None:
            self.dedupe = dedupe
        if compress is not None:
            self.compress = compress
        self.policy = policy
        self.new_cg_name = new_cg_name
        if wan_optimization is not None:
            self.wan_optimization = wan_optimization

    @property
    def display_name(self):
        """Gets the display_name of this CreateVolumeMirror.  # noqa: E501

        The name for the Mirror Job.  # noqa: E501

        :return: The display_name of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateVolumeMirror.

        The name for the Mirror Job.  # noqa: E501

        :param display_name: The display_name of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def remote_pool(self):
        """Gets the remote_pool of this CreateVolumeMirror.  # noqa: E501

        Pool ID on the remote VPSA where the Mirrored Volume will be created  # noqa: E501

        :return: The remote_pool of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._remote_pool

    @remote_pool.setter
    def remote_pool(self, remote_pool):
        """Sets the remote_pool of this CreateVolumeMirror.

        Pool ID on the remote VPSA where the Mirrored Volume will be created  # noqa: E501

        :param remote_pool: The remote_pool of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and remote_pool is None:
            raise ValueError("Invalid value for `remote_pool`, must not be `None`")  # noqa: E501

        self._remote_pool = remote_pool

    @property
    def dedupe(self):
        """Gets the dedupe of this CreateVolumeMirror.  # noqa: E501

        Enable Dedupe For Mirror.  # noqa: E501

        :return: The dedupe of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this CreateVolumeMirror.

        Enable Dedupe For Mirror.  # noqa: E501

        :param dedupe: The dedupe of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                dedupe not in allowed_values):
            raise ValueError(
                "Invalid value for `dedupe` ({0}), must be one of {1}"  # noqa: E501
                .format(dedupe, allowed_values)
            )

        self._dedupe = dedupe

    @property
    def compress(self):
        """Gets the compress of this CreateVolumeMirror.  # noqa: E501

        Enable compress For Mirror.  # noqa: E501

        :return: The compress of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CreateVolumeMirror.

        Enable compress For Mirror.  # noqa: E501

        :param compress: The compress of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                compress not in allowed_values):
            raise ValueError(
                "Invalid value for `compress` ({0}), must be one of {1}"  # noqa: E501
                .format(compress, allowed_values)
            )

        self._compress = compress

    @property
    def policy(self):
        """Gets the policy of this CreateVolumeMirror.  # noqa: E501

        Snapshot Policy ID for Remote Mirroring.  # noqa: E501

        :return: The policy of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this CreateVolumeMirror.

        Snapshot Policy ID for Remote Mirroring.  # noqa: E501

        :param policy: The policy of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and policy is None:
            raise ValueError("Invalid value for `policy`, must not be `None`")  # noqa: E501

        self._policy = policy

    @property
    def new_cg_name(self):
        """Gets the new_cg_name of this CreateVolumeMirror.  # noqa: E501

        Name for the mirrored Volume on the Remote VPSA.  # noqa: E501

        :return: The new_cg_name of this CreateVolumeMirror.  # noqa: E501
        :rtype: str
        """
        return self._new_cg_name

    @new_cg_name.setter
    def new_cg_name(self, new_cg_name):
        """Sets the new_cg_name of this CreateVolumeMirror.

        Name for the mirrored Volume on the Remote VPSA.  # noqa: E501

        :param new_cg_name: The new_cg_name of this CreateVolumeMirror.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and new_cg_name is None:
            raise ValueError("Invalid value for `new_cg_name`, must not be `None`")  # noqa: E501

        self._new_cg_name = new_cg_name

    @property
    def wan_optimization(self):
        """Gets the wan_optimization of this CreateVolumeMirror.  # noqa: E501


        :return: The wan_optimization of this CreateVolumeMirror.  # noqa: E501
        :rtype: bool
        """
        return self._wan_optimization

    @wan_optimization.setter
    def wan_optimization(self, wan_optimization):
        """Sets the wan_optimization of this CreateVolumeMirror.


        :param wan_optimization: The wan_optimization of this CreateVolumeMirror.  # noqa: E501
        :type: bool
        """

        self._wan_optimization = wan_optimization

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVolumeMirror, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVolumeMirror):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVolumeMirror):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20041ResponseUsers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'username': 'str',
        'email': 'str',
        'access_key': 'str',
        'primary': 'bool',
        'admin': 'bool',
        'locked': 'bool',
        'roles': 'list[InlineResponse20041ResponseRoles]',
        'display_timezone': 'str',
        'notify_on_events': 'bool',
        'zios_data': 'InlineResponse20041ResponseZiosData'
    }

    attribute_map = {
        'id': 'id',
        'username': 'username',
        'email': 'email',
        'access_key': 'access_key',
        'primary': 'primary',
        'admin': 'admin',
        'locked': 'locked',
        'roles': 'roles',
        'display_timezone': 'display_timezone',
        'notify_on_events': 'notify_on_events',
        'zios_data': 'zios_data'
    }

    def __init__(self, id=None, username=None, email=None, access_key=None, primary=None, admin=None, locked=None, roles=None, display_timezone=None, notify_on_events=None, zios_data=None, _configuration=None):  # noqa: E501
        """InlineResponse20041ResponseUsers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._username = None
        self._email = None
        self._access_key = None
        self._primary = None
        self._admin = None
        self._locked = None
        self._roles = None
        self._display_timezone = None
        self._notify_on_events = None
        self._zios_data = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if username is not None:
            self.username = username
        if email is not None:
            self.email = email
        if access_key is not None:
            self.access_key = access_key
        if primary is not None:
            self.primary = primary
        if admin is not None:
            self.admin = admin
        if locked is not None:
            self.locked = locked
        if roles is not None:
            self.roles = roles
        if display_timezone is not None:
            self.display_timezone = display_timezone
        if notify_on_events is not None:
            self.notify_on_events = notify_on_events
        if zios_data is not None:
            self.zios_data = zios_data

    @property
    def id(self):
        """Gets the id of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The id of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20041ResponseUsers.


        :param id: The id of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def username(self):
        """Gets the username of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The username of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this InlineResponse20041ResponseUsers.


        :param username: The username of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def email(self):
        """Gets the email of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The email of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this InlineResponse20041ResponseUsers.


        :param email: The email of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def access_key(self):
        """Gets the access_key of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The access_key of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this InlineResponse20041ResponseUsers.


        :param access_key: The access_key of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def primary(self):
        """Gets the primary of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The primary of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this InlineResponse20041ResponseUsers.


        :param primary: The primary of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: bool
        """

        self._primary = primary

    @property
    def admin(self):
        """Gets the admin of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The admin of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this InlineResponse20041ResponseUsers.


        :param admin: The admin of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    @property
    def locked(self):
        """Gets the locked of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The locked of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this InlineResponse20041ResponseUsers.


        :param locked: The locked of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def roles(self):
        """Gets the roles of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The roles of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: list[InlineResponse20041ResponseRoles]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this InlineResponse20041ResponseUsers.


        :param roles: The roles of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: list[InlineResponse20041ResponseRoles]
        """

        self._roles = roles

    @property
    def display_timezone(self):
        """Gets the display_timezone of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The display_timezone of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: str
        """
        return self._display_timezone

    @display_timezone.setter
    def display_timezone(self, display_timezone):
        """Sets the display_timezone of this InlineResponse20041ResponseUsers.


        :param display_timezone: The display_timezone of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: str
        """

        self._display_timezone = display_timezone

    @property
    def notify_on_events(self):
        """Gets the notify_on_events of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The notify_on_events of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: bool
        """
        return self._notify_on_events

    @notify_on_events.setter
    def notify_on_events(self, notify_on_events):
        """Sets the notify_on_events of this InlineResponse20041ResponseUsers.


        :param notify_on_events: The notify_on_events of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: bool
        """

        self._notify_on_events = notify_on_events

    @property
    def zios_data(self):
        """Gets the zios_data of this InlineResponse20041ResponseUsers.  # noqa: E501


        :return: The zios_data of this InlineResponse20041ResponseUsers.  # noqa: E501
        :rtype: InlineResponse20041ResponseZiosData
        """
        return self._zios_data

    @zios_data.setter
    def zios_data(self, zios_data):
        """Sets the zios_data of this InlineResponse20041ResponseUsers.


        :param zios_data: The zios_data of this InlineResponse20041ResponseUsers.  # noqa: E501
        :type: InlineResponse20041ResponseZiosData
        """

        self._zios_data = zios_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20041ResponseUsers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20041ResponseUsers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20041ResponseUsers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateEndpoint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'endpoint_name': 'str',
        'endpoint_method': 'str',
        'config': 'str'
    }

    attribute_map = {
        'endpoint_name': 'endpoint_name',
        'endpoint_method': 'endpoint_method',
        'config': 'config'
    }

    def __init__(self, endpoint_name=None, endpoint_method=None, config=None, _configuration=None):  # noqa: E501
        """CreateEndpoint - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._endpoint_name = None
        self._endpoint_method = None
        self._config = None
        self.discriminator = None

        self.endpoint_name = endpoint_name
        self.endpoint_method = endpoint_method
        self.config = config

    @property
    def endpoint_name(self):
        """Gets the endpoint_name of this CreateEndpoint.  # noqa: E501

        Endpoint name  # noqa: E501

        :return: The endpoint_name of this CreateEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_name

    @endpoint_name.setter
    def endpoint_name(self, endpoint_name):
        """Sets the endpoint_name of this CreateEndpoint.

        Endpoint name  # noqa: E501

        :param endpoint_name: The endpoint_name of this CreateEndpoint.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and endpoint_name is None:
            raise ValueError("Invalid value for `endpoint_name`, must not be `None`")  # noqa: E501

        self._endpoint_name = endpoint_name

    @property
    def endpoint_method(self):
        """Gets the endpoint_method of this CreateEndpoint.  # noqa: E501

        Endpoint upload method  # noqa: E501

        :return: The endpoint_method of this CreateEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_method

    @endpoint_method.setter
    def endpoint_method(self, endpoint_method):
        """Sets the endpoint_method of this CreateEndpoint.

        Endpoint upload method  # noqa: E501

        :param endpoint_method: The endpoint_method of this CreateEndpoint.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and endpoint_method is None:
            raise ValueError("Invalid value for `endpoint_method`, must not be `None`")  # noqa: E501
        allowed_values = ["s3_aws", "s3_zios", "ftp"]  # noqa: E501
        if (self._configuration.client_side_validation and
                endpoint_method not in allowed_values):
            raise ValueError(
                "Invalid value for `endpoint_method` ({0}), must be one of {1}"  # noqa: E501
                .format(endpoint_method, allowed_values)
            )

        self._endpoint_method = endpoint_method

    @property
    def config(self):
        """Gets the config of this CreateEndpoint.  # noqa: E501

        Endpoint configuration JSON, depending on the chosen upload method. For 's3_aws' and 's3_zios' methods, config should include 'access_key', 'secret_key' and 'region'. For 's3_zios' method, config should also include 'endpoint'. For 'ftp' method, config should include 'server', 'user', 'password', 'use_proxy' (boolean '0' or '1').  # noqa: E501

        :return: The config of this CreateEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this CreateEndpoint.

        Endpoint configuration JSON, depending on the chosen upload method. For 's3_aws' and 's3_zios' methods, config should include 'access_key', 'secret_key' and 'region'. For 's3_zios' method, config should also include 'endpoint'. For 'ftp' method, config should include 'server', 'user', 'password', 'use_proxy' (boolean '0' or '1').  # noqa: E501

        :param config: The config of this CreateEndpoint.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and config is None:
            raise ValueError("Invalid value for `config`, must not be `None`")  # noqa: E501

        self._config = config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateEndpoint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateEndpoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateEndpoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class DiscoverRemoteVpsa(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ip': 'str',
        'user': 'str',
        'password': 'str',
        'interface': 'str',
        'proxyhost': 'str',
        'proxyport': 'str',
        'proxytype': 'str',
        'proxyusername': 'str',
        'proxypassword': 'str'
    }

    attribute_map = {
        'ip': 'ip',
        'user': 'user',
        'password': 'password',
        'interface': 'interface',
        'proxyhost': 'proxyhost',
        'proxyport': 'proxyport',
        'proxytype': 'proxytype',
        'proxyusername': 'proxyusername',
        'proxypassword': 'proxypassword'
    }

    def __init__(self, ip=None, user=None, password=None, interface='fe', proxyhost=None, proxyport=None, proxytype=None, proxyusername=None, proxypassword=None, _configuration=None):  # noqa: E501
        """DiscoverRemoteVpsa - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ip = None
        self._user = None
        self._password = None
        self._interface = None
        self._proxyhost = None
        self._proxyport = None
        self._proxytype = None
        self._proxyusername = None
        self._proxypassword = None
        self.discriminator = None

        self.ip = ip
        self.user = user
        self.password = password
        if interface is not None:
            self.interface = interface
        if proxyhost is not None:
            self.proxyhost = proxyhost
        if proxyport is not None:
            self.proxyport = proxyport
        if proxytype is not None:
            self.proxytype = proxytype
        if proxyusername is not None:
            self.proxyusername = proxyusername
        if proxypassword is not None:
            self.proxypassword = proxypassword

    @property
    def ip(self):
        """Gets the ip of this DiscoverRemoteVpsa.  # noqa: E501

        IP of VPSA to discover  # noqa: E501

        :return: The ip of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this DiscoverRemoteVpsa.

        IP of VPSA to discover  # noqa: E501

        :param ip: The ip of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def user(self):
        """Gets the user of this DiscoverRemoteVpsa.  # noqa: E501

        username of VPSA to discover  # noqa: E501

        :return: The user of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this DiscoverRemoteVpsa.

        username of VPSA to discover  # noqa: E501

        :param user: The user of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def password(self):
        """Gets the password of this DiscoverRemoteVpsa.  # noqa: E501

        password of VPSA to discover  # noqa: E501

        :return: The password of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this DiscoverRemoteVpsa.

        password of VPSA to discover  # noqa: E501

        :param password: The password of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def interface(self):
        """Gets the interface of this DiscoverRemoteVpsa.  # noqa: E501

        Set interface to use for connecting the remote vpsa  # noqa: E501

        :return: The interface of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._interface

    @interface.setter
    def interface(self, interface):
        """Sets the interface of this DiscoverRemoteVpsa.

        Set interface to use for connecting the remote vpsa  # noqa: E501

        :param interface: The interface of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """
        allowed_values = ["public", "vni0", "fe"]  # noqa: E501
        if (self._configuration.client_side_validation and
                interface not in allowed_values):
            raise ValueError(
                "Invalid value for `interface` ({0}), must be one of {1}"  # noqa: E501
                .format(interface, allowed_values)
            )

        self._interface = interface

    @property
    def proxyhost(self):
        """Gets the proxyhost of this DiscoverRemoteVpsa.  # noqa: E501

        If using proxy, the proxy host  # noqa: E501

        :return: The proxyhost of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._proxyhost

    @proxyhost.setter
    def proxyhost(self, proxyhost):
        """Sets the proxyhost of this DiscoverRemoteVpsa.

        If using proxy, the proxy host  # noqa: E501

        :param proxyhost: The proxyhost of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """

        self._proxyhost = proxyhost

    @property
    def proxyport(self):
        """Gets the proxyport of this DiscoverRemoteVpsa.  # noqa: E501

        If using proxy, the proxy port  # noqa: E501

        :return: The proxyport of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._proxyport

    @proxyport.setter
    def proxyport(self, proxyport):
        """Sets the proxyport of this DiscoverRemoteVpsa.

        If using proxy, the proxy port  # noqa: E501

        :param proxyport: The proxyport of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """

        self._proxyport = proxyport

    @property
    def proxytype(self):
        """Gets the proxytype of this DiscoverRemoteVpsa.  # noqa: E501

        If using proxy, the proxy type  # noqa: E501

        :return: The proxytype of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._proxytype

    @proxytype.setter
    def proxytype(self, proxytype):
        """Sets the proxytype of this DiscoverRemoteVpsa.

        If using proxy, the proxy type  # noqa: E501

        :param proxytype: The proxytype of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """
        allowed_values = ["http", "http10", "socks4_hostname", "socks5", "socks4", "socks4a"]  # noqa: E501
        if (self._configuration.client_side_validation and
                proxytype not in allowed_values):
            raise ValueError(
                "Invalid value for `proxytype` ({0}), must be one of {1}"  # noqa: E501
                .format(proxytype, allowed_values)
            )

        self._proxytype = proxytype

    @property
    def proxyusername(self):
        """Gets the proxyusername of this DiscoverRemoteVpsa.  # noqa: E501

        If using proxy with authentication, the proxy username  # noqa: E501

        :return: The proxyusername of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._proxyusername

    @proxyusername.setter
    def proxyusername(self, proxyusername):
        """Sets the proxyusername of this DiscoverRemoteVpsa.

        If using proxy with authentication, the proxy username  # noqa: E501

        :param proxyusername: The proxyusername of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """

        self._proxyusername = proxyusername

    @property
    def proxypassword(self):
        """Gets the proxypassword of this DiscoverRemoteVpsa.  # noqa: E501

        If using proxy with authentication, the proxy user password  # noqa: E501

        :return: The proxypassword of this DiscoverRemoteVpsa.  # noqa: E501
        :rtype: str
        """
        return self._proxypassword

    @proxypassword.setter
    def proxypassword(self, proxypassword):
        """Sets the proxypassword of this DiscoverRemoteVpsa.

        If using proxy with authentication, the proxy user password  # noqa: E501

        :param proxypassword: The proxypassword of this DiscoverRemoteVpsa.  # noqa: E501
        :type: str
        """

        self._proxypassword = proxypassword

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DiscoverRemoteVpsa, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiscoverRemoteVpsa):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DiscoverRemoteVpsa):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200123ResponseRemoteCloneJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_name': 'str',
        'job_display_name': 'str',
        'mode': 'str',
        'comment': 'str',
        'src': 'InlineResponse200123ResponseRemoteCloneJobSrc',
        'dst': 'InlineResponse200123ResponseRemoteCloneJobDst',
        'status': 'str',
        'compress': 'str',
        'dedupe': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'job_name': 'job_name',
        'job_display_name': 'job_display_name',
        'mode': 'mode',
        'comment': 'comment',
        'src': 'src',
        'dst': 'dst',
        'status': 'status',
        'compress': 'compress',
        'dedupe': 'dedupe',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, job_name=None, job_display_name=None, mode=None, comment=None, src=None, dst=None, status=None, compress=None, dedupe=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse200123ResponseRemoteCloneJob - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._job_name = None
        self._job_display_name = None
        self._mode = None
        self._comment = None
        self._src = None
        self._dst = None
        self._status = None
        self._compress = None
        self._dedupe = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if job_name is not None:
            self.job_name = job_name
        if job_display_name is not None:
            self.job_display_name = job_display_name
        if mode is not None:
            self.mode = mode
        if comment is not None:
            self.comment = comment
        if src is not None:
            self.src = src
        if dst is not None:
            self.dst = dst
        if status is not None:
            self.status = status
        if compress is not None:
            self.compress = compress
        if dedupe is not None:
            self.dedupe = dedupe
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def job_name(self):
        """Gets the job_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The job_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this InlineResponse200123ResponseRemoteCloneJob.


        :param job_name: The job_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_display_name(self):
        """Gets the job_display_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The job_display_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._job_display_name

    @job_display_name.setter
    def job_display_name(self, job_display_name):
        """Sets the job_display_name of this InlineResponse200123ResponseRemoteCloneJob.


        :param job_display_name: The job_display_name of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._job_display_name = job_display_name

    @property
    def mode(self):
        """Gets the mode of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The mode of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this InlineResponse200123ResponseRemoteCloneJob.


        :param mode: The mode of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def comment(self):
        """Gets the comment of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The comment of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse200123ResponseRemoteCloneJob.


        :param comment: The comment of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def src(self):
        """Gets the src of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The src of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: InlineResponse200123ResponseRemoteCloneJobSrc
        """
        return self._src

    @src.setter
    def src(self, src):
        """Sets the src of this InlineResponse200123ResponseRemoteCloneJob.


        :param src: The src of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: InlineResponse200123ResponseRemoteCloneJobSrc
        """

        self._src = src

    @property
    def dst(self):
        """Gets the dst of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The dst of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: InlineResponse200123ResponseRemoteCloneJobDst
        """
        return self._dst

    @dst.setter
    def dst(self, dst):
        """Sets the dst of this InlineResponse200123ResponseRemoteCloneJob.


        :param dst: The dst of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: InlineResponse200123ResponseRemoteCloneJobDst
        """

        self._dst = dst

    @property
    def status(self):
        """Gets the status of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The status of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200123ResponseRemoteCloneJob.


        :param status: The status of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def compress(self):
        """Gets the compress of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The compress of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this InlineResponse200123ResponseRemoteCloneJob.


        :param compress: The compress of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._compress = compress

    @property
    def dedupe(self):
        """Gets the dedupe of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The dedupe of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this InlineResponse200123ResponseRemoteCloneJob.


        :param dedupe: The dedupe of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._dedupe = dedupe

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The created_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200123ResponseRemoteCloneJob.


        :param created_at: The created_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501


        :return: The modified_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200123ResponseRemoteCloneJob.


        :param modified_at: The modified_at of this InlineResponse200123ResponseRemoteCloneJob.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200123ResponseRemoteCloneJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200123ResponseRemoteCloneJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200123ResponseRemoteCloneJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.remote_object_storage_api import RemoteObjectStorageApi  # noqa: E501
from Vpsa.rest import ApiException


class TestRemoteObjectStorageApi(unittest.TestCase):
    """RemoteObjectStorageApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.remote_object_storage_api.RemoteObjectStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_backup_jobs_rate_limit(self):
        """Test case for backup_jobs_rate_limit

        """
        pass

    def test_backup_jobs_update_compression(self):
        """Test case for backup_jobs_update_compression

        """
        pass

    def test_break_ros_backup_job(self):
        """Test case for break_ros_backup_job

        """
        pass

    def test_break_ros_restore_job(self):
        """Test case for break_ros_restore_job

        """
        pass

    def test_change_ros_restore_job_mode(self):
        """Test case for change_ros_restore_job_mode

        """
        pass

    def test_create_ros_backup_job(self):
        """Test case for create_ros_backup_job

        """
        pass

    def test_create_ros_destination(self):
        """Test case for create_ros_destination

        """
        pass

    def test_create_ros_restore_job(self):
        """Test case for create_ros_restore_job

        """
        pass

    def test_get_all_ros_backup_jobs(self):
        """Test case for get_all_ros_backup_jobs

        """
        pass

    def test_get_all_ros_destination_backup_jobs(self):
        """Test case for get_all_ros_destination_backup_jobs

        """
        pass

    def test_get_all_ros_destination_restore_jobs(self):
        """Test case for get_all_ros_destination_restore_jobs

        """
        pass

    def test_get_all_ros_destinations(self):
        """Test case for get_all_ros_destinations

        """
        pass

    def test_get_all_ros_restore_jobs(self):
        """Test case for get_all_ros_restore_jobs

        """
        pass

    def test_get_ros_backup_job(self):
        """Test case for get_ros_backup_job

        """
        pass

    def test_get_ros_backup_job_performance(self):
        """Test case for get_ros_backup_job_performance

        """
        pass

    def test_get_ros_destination(self):
        """Test case for get_ros_destination

        """
        pass

    def test_get_ros_restore_job(self):
        """Test case for get_ros_restore_job

        """
        pass

    def test_get_ros_restore_job_performance(self):
        """Test case for get_ros_restore_job_performance

        """
        pass

    def test_pause_ros_backup_job(self):
        """Test case for pause_ros_backup_job

        """
        pass

    def test_pause_ros_restore_job(self):
        """Test case for pause_ros_restore_job

        """
        pass

    def test_remove_ros_destination(self):
        """Test case for remove_ros_destination

        """
        pass

    def test_replace_ros_backup_job_snapshot_policy(self):
        """Test case for replace_ros_backup_job_snapshot_policy

        """
        pass

    def test_resume_ros_backup_job(self):
        """Test case for resume_ros_backup_job

        """
        pass

    def test_resume_ros_restore_job(self):
        """Test case for resume_ros_restore_job

        """
        pass

    def test_set_obs_backup_job_class(self):
        """Test case for set_obs_backup_job_class

        """
        pass

    def test_update_ros_destination(self):
        """Test case for update_ros_destination

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CreateObjectStorageAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'object_storage_account_name': 'str',
        'object_storage_admin_username': 'str',
        'object_storage_admin_password': 'str',
        'user_id': 'int',
        'moderate': 'bool'
    }

    attribute_map = {
        'object_storage_account_name': 'object_storage_account_name',
        'object_storage_admin_username': 'object_storage_admin_username',
        'object_storage_admin_password': 'object_storage_admin_password',
        'user_id': 'user_id',
        'moderate': 'moderate'
    }

    def __init__(self, object_storage_account_name=None, object_storage_admin_username=None, object_storage_admin_password=None, user_id=None, moderate=None, _configuration=None):  # noqa: E501
        """CreateObjectStorageAccount - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._object_storage_account_name = None
        self._object_storage_admin_username = None
        self._object_storage_admin_password = None
        self._user_id = None
        self._moderate = None
        self.discriminator = None

        self.object_storage_account_name = object_storage_account_name
        self.object_storage_admin_username = object_storage_admin_username
        self.object_storage_admin_password = object_storage_admin_password
        self.user_id = user_id
        if moderate is not None:
            self.moderate = moderate

    @property
    def object_storage_account_name(self):
        """Gets the object_storage_account_name of this CreateObjectStorageAccount.  # noqa: E501

        The new account name.  # noqa: E501

        :return: The object_storage_account_name of this CreateObjectStorageAccount.  # noqa: E501
        :rtype: str
        """
        return self._object_storage_account_name

    @object_storage_account_name.setter
    def object_storage_account_name(self, object_storage_account_name):
        """Sets the object_storage_account_name of this CreateObjectStorageAccount.

        The new account name.  # noqa: E501

        :param object_storage_account_name: The object_storage_account_name of this CreateObjectStorageAccount.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and object_storage_account_name is None:
            raise ValueError("Invalid value for `object_storage_account_name`, must not be `None`")  # noqa: E501

        self._object_storage_account_name = object_storage_account_name

    @property
    def object_storage_admin_username(self):
        """Gets the object_storage_admin_username of this CreateObjectStorageAccount.  # noqa: E501

        The new account administrator username. The administrator user will be created with the account.  # noqa: E501

        :return: The object_storage_admin_username of this CreateObjectStorageAccount.  # noqa: E501
        :rtype: str
        """
        return self._object_storage_admin_username

    @object_storage_admin_username.setter
    def object_storage_admin_username(self, object_storage_admin_username):
        """Sets the object_storage_admin_username of this CreateObjectStorageAccount.

        The new account administrator username. The administrator user will be created with the account.  # noqa: E501

        :param object_storage_admin_username: The object_storage_admin_username of this CreateObjectStorageAccount.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and object_storage_admin_username is None:
            raise ValueError("Invalid value for `object_storage_admin_username`, must not be `None`")  # noqa: E501

        self._object_storage_admin_username = object_storage_admin_username

    @property
    def object_storage_admin_password(self):
        """Gets the object_storage_admin_password of this CreateObjectStorageAccount.  # noqa: E501

        The new account administrator password. The administrator user will be created with the account.  # noqa: E501

        :return: The object_storage_admin_password of this CreateObjectStorageAccount.  # noqa: E501
        :rtype: str
        """
        return self._object_storage_admin_password

    @object_storage_admin_password.setter
    def object_storage_admin_password(self, object_storage_admin_password):
        """Sets the object_storage_admin_password of this CreateObjectStorageAccount.

        The new account administrator password. The administrator user will be created with the account.  # noqa: E501

        :param object_storage_admin_password: The object_storage_admin_password of this CreateObjectStorageAccount.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and object_storage_admin_password is None:
            raise ValueError("Invalid value for `object_storage_admin_password`, must not be `None`")  # noqa: E501

        self._object_storage_admin_password = object_storage_admin_password

    @property
    def user_id(self):
        """Gets the user_id of this CreateObjectStorageAccount.  # noqa: E501

        The ID of the user that creates the account.  # noqa: E501

        :return: The user_id of this CreateObjectStorageAccount.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CreateObjectStorageAccount.

        The ID of the user that creates the account.  # noqa: E501

        :param user_id: The user_id of this CreateObjectStorageAccount.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def moderate(self):
        """Gets the moderate of this CreateObjectStorageAccount.  # noqa: E501

        When false, the account will be immediately created. When true, only a request will be created and it should be approved by an administrator. Default is false. Usable only for administrator or auto-approved user.  # noqa: E501

        :return: The moderate of this CreateObjectStorageAccount.  # noqa: E501
        :rtype: bool
        """
        return self._moderate

    @moderate.setter
    def moderate(self, moderate):
        """Sets the moderate of this CreateObjectStorageAccount.

        When false, the account will be immediately created. When true, only a request will be created and it should be approved by an administrator. Default is false. Usable only for administrator or auto-approved user.  # noqa: E501

        :param moderate: The moderate of this CreateObjectStorageAccount.  # noqa: E501
        :type: bool
        """

        self._moderate = moderate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateObjectStorageAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateObjectStorageAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateObjectStorageAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.models.inline_response200135_vcs import InlineResponse200135Vcs  # noqa: E501
from CommandCenter.rest import ApiException


class TestInlineResponse200135Vcs(unittest.TestCase):
    """InlineResponse200135Vcs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse200135Vcs(self):
        """Test InlineResponse200135Vcs"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CommandCenter.models.inline_response200135_vcs.InlineResponse200135Vcs()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200203ResponseVolumes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'cg_display_name': 'str',
        'cg_name': 'str',
        'cg_user_created': 'str',
        'pool_display_name': 'str',
        'pool_name': 'str',
        'status': 'str',
        'virtual_capacity': 'int',
        'server_name': 'str',
        'data_type': 'str',
        'thin': 'str',
        'encryption': 'str',
        'encryption_key_size': 'str',
        'allocated_capacity': 'float',
        'data_copies_capacity': 'float',
        'access_type': 'str',
        'read_only': 'str',
        'nfs_export_path': 'str',
        'smb_export_path': 'str',
        'mount_sync': 'str',
        'atime_update': 'str',
        'ext_metering': 'str',
        'images_repo': 'str',
        'nfs_root_squash': 'str',
        'smb_only': 'str',
        'smb_guest': 'str',
        'smb_windows_acl': 'str',
        'smb_map_archive': 'str',
        'smb_file_create_mask': 'str',
        'smb_dir_create_mask': 'str',
        'smb_aio_size': 'int',
        'smb_browseable': 'str',
        'smb_hidden_files': 'str',
        'smb_encryption_mode': 'str',
        'smb_hide_unreadable': 'str',
        'smb_hide_unwriteable': 'str',
        'smb_hide_dot_files': 'str',
        'smb_store_dos_attributes': 'str',
        'capacity_history': 'int',
        'alert_mode': 'int',
        'uquota_state': 'str',
        'gquota_state': 'str',
        'pquota_state': 'str',
        'target': 'str',
        'lun': 'str',
        'cache': 'str',
        'tenant_id': 'int',
        'has_mirror': 'str',
        'has_backup': 'str',
        'has_snapshots': 'str',
        'shadow_copy_enabled': 'str',
        'is_shadow_copy_clone': 'str',
        'read_iops_limit': 'str',
        'read_mbps_limit': 'str',
        'write_iops_limit': 'str',
        'write_mbps_limit': 'str',
        'thresholds': 'str',
        'comment': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'cg_display_name': 'cg_display_name',
        'cg_name': 'cg_name',
        'cg_user_created': 'cg_user_created',
        'pool_display_name': 'pool_display_name',
        'pool_name': 'pool_name',
        'status': 'status',
        'virtual_capacity': 'virtual_capacity',
        'server_name': 'server_name',
        'data_type': 'data_type',
        'thin': 'thin',
        'encryption': 'encryption',
        'encryption_key_size': 'encryption_key_size',
        'allocated_capacity': 'allocated_capacity',
        'data_copies_capacity': 'data_copies_capacity',
        'access_type': 'access_type',
        'read_only': 'read_only',
        'nfs_export_path': 'nfs_export_path',
        'smb_export_path': 'smb_export_path',
        'mount_sync': 'mount_sync',
        'atime_update': 'atime_update',
        'ext_metering': 'ext_metering',
        'images_repo': 'images_repo',
        'nfs_root_squash': 'nfs_root_squash',
        'smb_only': 'smb_only',
        'smb_guest': 'smb_guest',
        'smb_windows_acl': 'smb_windows_acl',
        'smb_map_archive': 'smb_map_archive',
        'smb_file_create_mask': 'smb_file_create_mask',
        'smb_dir_create_mask': 'smb_dir_create_mask',
        'smb_aio_size': 'smb_aio_size',
        'smb_browseable': 'smb_browseable',
        'smb_hidden_files': 'smb_hidden_files',
        'smb_encryption_mode': 'smb_encryption_mode',
        'smb_hide_unreadable': 'smb_hide_unreadable',
        'smb_hide_unwriteable': 'smb_hide_unwriteable',
        'smb_hide_dot_files': 'smb_hide_dot_files',
        'smb_store_dos_attributes': 'smb_store_dos_attributes',
        'capacity_history': 'capacity_history',
        'alert_mode': 'alert_mode',
        'uquota_state': 'uquota_state',
        'gquota_state': 'gquota_state',
        'pquota_state': 'pquota_state',
        'target': 'target',
        'lun': 'lun',
        'cache': 'cache',
        'tenant_id': 'tenant_id',
        'has_mirror': 'has_mirror',
        'has_backup': 'has_backup',
        'has_snapshots': 'has_snapshots',
        'shadow_copy_enabled': 'shadow_copy_enabled',
        'is_shadow_copy_clone': 'is_shadow_copy_clone',
        'read_iops_limit': 'read_iops_limit',
        'read_mbps_limit': 'read_mbps_limit',
        'write_iops_limit': 'write_iops_limit',
        'write_mbps_limit': 'write_mbps_limit',
        'thresholds': 'thresholds',
        'comment': 'comment',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, cg_display_name=None, cg_name=None, cg_user_created=None, pool_display_name=None, pool_name=None, status=None, virtual_capacity=None, server_name=None, data_type=None, thin=None, encryption=None, encryption_key_size=None, allocated_capacity=None, data_copies_capacity=None, access_type=None, read_only=None, nfs_export_path=None, smb_export_path=None, mount_sync=None, atime_update=None, ext_metering=None, images_repo=None, nfs_root_squash=None, smb_only=None, smb_guest=None, smb_windows_acl=None, smb_map_archive=None, smb_file_create_mask=None, smb_dir_create_mask=None, smb_aio_size=None, smb_browseable=None, smb_hidden_files=None, smb_encryption_mode=None, smb_hide_unreadable=None, smb_hide_unwriteable=None, smb_hide_dot_files=None, smb_store_dos_attributes=None, capacity_history=None, alert_mode=None, uquota_state=None, gquota_state=None, pquota_state=None, target=None, lun=None, cache=None, tenant_id=None, has_mirror=None, has_backup=None, has_snapshots=None, shadow_copy_enabled=None, is_shadow_copy_clone=None, read_iops_limit=None, read_mbps_limit=None, write_iops_limit=None, write_mbps_limit=None, thresholds=None, comment=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse200203ResponseVolumes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._cg_display_name = None
        self._cg_name = None
        self._cg_user_created = None
        self._pool_display_name = None
        self._pool_name = None
        self._status = None
        self._virtual_capacity = None
        self._server_name = None
        self._data_type = None
        self._thin = None
        self._encryption = None
        self._encryption_key_size = None
        self._allocated_capacity = None
        self._data_copies_capacity = None
        self._access_type = None
        self._read_only = None
        self._nfs_export_path = None
        self._smb_export_path = None
        self._mount_sync = None
        self._atime_update = None
        self._ext_metering = None
        self._images_repo = None
        self._nfs_root_squash = None
        self._smb_only = None
        self._smb_guest = None
        self._smb_windows_acl = None
        self._smb_map_archive = None
        self._smb_file_create_mask = None
        self._smb_dir_create_mask = None
        self._smb_aio_size = None
        self._smb_browseable = None
        self._smb_hidden_files = None
        self._smb_encryption_mode = None
        self._smb_hide_unreadable = None
        self._smb_hide_unwriteable = None
        self._smb_hide_dot_files = None
        self._smb_store_dos_attributes = None
        self._capacity_history = None
        self._alert_mode = None
        self._uquota_state = None
        self._gquota_state = None
        self._pquota_state = None
        self._target = None
        self._lun = None
        self._cache = None
        self._tenant_id = None
        self._has_mirror = None
        self._has_backup = None
        self._has_snapshots = None
        self._shadow_copy_enabled = None
        self._is_shadow_copy_clone = None
        self._read_iops_limit = None
        self._read_mbps_limit = None
        self._write_iops_limit = None
        self._write_mbps_limit = None
        self._thresholds = None
        self._comment = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if cg_display_name is not None:
            self.cg_display_name = cg_display_name
        if cg_name is not None:
            self.cg_name = cg_name
        if cg_user_created is not None:
            self.cg_user_created = cg_user_created
        if pool_display_name is not None:
            self.pool_display_name = pool_display_name
        if pool_name is not None:
            self.pool_name = pool_name
        if status is not None:
            self.status = status
        if virtual_capacity is not None:
            self.virtual_capacity = virtual_capacity
        if server_name is not None:
            self.server_name = server_name
        if data_type is not None:
            self.data_type = data_type
        if thin is not None:
            self.thin = thin
        if encryption is not None:
            self.encryption = encryption
        if encryption_key_size is not None:
            self.encryption_key_size = encryption_key_size
        if allocated_capacity is not None:
            self.allocated_capacity = allocated_capacity
        if data_copies_capacity is not None:
            self.data_copies_capacity = data_copies_capacity
        if access_type is not None:
            self.access_type = access_type
        if read_only is not None:
            self.read_only = read_only
        if nfs_export_path is not None:
            self.nfs_export_path = nfs_export_path
        if smb_export_path is not None:
            self.smb_export_path = smb_export_path
        if mount_sync is not None:
            self.mount_sync = mount_sync
        if atime_update is not None:
            self.atime_update = atime_update
        if ext_metering is not None:
            self.ext_metering = ext_metering
        if images_repo is not None:
            self.images_repo = images_repo
        if nfs_root_squash is not None:
            self.nfs_root_squash = nfs_root_squash
        if smb_only is not None:
            self.smb_only = smb_only
        if smb_guest is not None:
            self.smb_guest = smb_guest
        if smb_windows_acl is not None:
            self.smb_windows_acl = smb_windows_acl
        if smb_map_archive is not None:
            self.smb_map_archive = smb_map_archive
        if smb_file_create_mask is not None:
            self.smb_file_create_mask = smb_file_create_mask
        if smb_dir_create_mask is not None:
            self.smb_dir_create_mask = smb_dir_create_mask
        if smb_aio_size is not None:
            self.smb_aio_size = smb_aio_size
        if smb_browseable is not None:
            self.smb_browseable = smb_browseable
        if smb_hidden_files is not None:
            self.smb_hidden_files = smb_hidden_files
        if smb_encryption_mode is not None:
            self.smb_encryption_mode = smb_encryption_mode
        if smb_hide_unreadable is not None:
            self.smb_hide_unreadable = smb_hide_unreadable
        if smb_hide_unwriteable is not None:
            self.smb_hide_unwriteable = smb_hide_unwriteable
        if smb_hide_dot_files is not None:
            self.smb_hide_dot_files = smb_hide_dot_files
        if smb_store_dos_attributes is not None:
            self.smb_store_dos_attributes = smb_store_dos_attributes
        if capacity_history is not None:
            self.capacity_history = capacity_history
        if alert_mode is not None:
            self.alert_mode = alert_mode
        if uquota_state is not None:
            self.uquota_state = uquota_state
        if gquota_state is not None:
            self.gquota_state = gquota_state
        if pquota_state is not None:
            self.pquota_state = pquota_state
        if target is not None:
            self.target = target
        if lun is not None:
            self.lun = lun
        if cache is not None:
            self.cache = cache
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if has_mirror is not None:
            self.has_mirror = has_mirror
        if has_backup is not None:
            self.has_backup = has_backup
        if has_snapshots is not None:
            self.has_snapshots = has_snapshots
        if shadow_copy_enabled is not None:
            self.shadow_copy_enabled = shadow_copy_enabled
        if is_shadow_copy_clone is not None:
            self.is_shadow_copy_clone = is_shadow_copy_clone
        if read_iops_limit is not None:
            self.read_iops_limit = read_iops_limit
        if read_mbps_limit is not None:
            self.read_mbps_limit = read_mbps_limit
        if write_iops_limit is not None:
            self.write_iops_limit = write_iops_limit
        if write_mbps_limit is not None:
            self.write_mbps_limit = write_mbps_limit
        if thresholds is not None:
            self.thresholds = thresholds
        if comment is not None:
            self.comment = comment
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200203ResponseVolumes.


        :param name: The name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200203ResponseVolumes.


        :param display_name: The display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def cg_display_name(self):
        """Gets the cg_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The cg_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_display_name

    @cg_display_name.setter
    def cg_display_name(self, cg_display_name):
        """Sets the cg_display_name of this InlineResponse200203ResponseVolumes.


        :param cg_display_name: The cg_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_display_name = cg_display_name

    @property
    def cg_name(self):
        """Gets the cg_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The cg_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_name

    @cg_name.setter
    def cg_name(self, cg_name):
        """Sets the cg_name of this InlineResponse200203ResponseVolumes.


        :param cg_name: The cg_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_name = cg_name

    @property
    def cg_user_created(self):
        """Gets the cg_user_created of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The cg_user_created of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_user_created

    @cg_user_created.setter
    def cg_user_created(self, cg_user_created):
        """Sets the cg_user_created of this InlineResponse200203ResponseVolumes.


        :param cg_user_created: The cg_user_created of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_user_created = cg_user_created

    @property
    def pool_display_name(self):
        """Gets the pool_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The pool_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_display_name

    @pool_display_name.setter
    def pool_display_name(self, pool_display_name):
        """Sets the pool_display_name of this InlineResponse200203ResponseVolumes.


        :param pool_display_name: The pool_display_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_display_name = pool_display_name

    @property
    def pool_name(self):
        """Gets the pool_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The pool_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_name

    @pool_name.setter
    def pool_name(self, pool_name):
        """Sets the pool_name of this InlineResponse200203ResponseVolumes.


        :param pool_name: The pool_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_name = pool_name

    @property
    def status(self):
        """Gets the status of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The status of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200203ResponseVolumes.


        :param status: The status of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def virtual_capacity(self):
        """Gets the virtual_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The virtual_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._virtual_capacity

    @virtual_capacity.setter
    def virtual_capacity(self, virtual_capacity):
        """Sets the virtual_capacity of this InlineResponse200203ResponseVolumes.


        :param virtual_capacity: The virtual_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._virtual_capacity = virtual_capacity

    @property
    def server_name(self):
        """Gets the server_name of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The server_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this InlineResponse200203ResponseVolumes.


        :param server_name: The server_name of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def data_type(self):
        """Gets the data_type of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The data_type of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this InlineResponse200203ResponseVolumes.


        :param data_type: The data_type of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def thin(self):
        """Gets the thin of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The thin of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._thin

    @thin.setter
    def thin(self, thin):
        """Sets the thin of this InlineResponse200203ResponseVolumes.


        :param thin: The thin of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._thin = thin

    @property
    def encryption(self):
        """Gets the encryption of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The encryption of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._encryption

    @encryption.setter
    def encryption(self, encryption):
        """Sets the encryption of this InlineResponse200203ResponseVolumes.


        :param encryption: The encryption of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._encryption = encryption

    @property
    def encryption_key_size(self):
        """Gets the encryption_key_size of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The encryption_key_size of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._encryption_key_size

    @encryption_key_size.setter
    def encryption_key_size(self, encryption_key_size):
        """Sets the encryption_key_size of this InlineResponse200203ResponseVolumes.


        :param encryption_key_size: The encryption_key_size of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._encryption_key_size = encryption_key_size

    @property
    def allocated_capacity(self):
        """Gets the allocated_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The allocated_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._allocated_capacity

    @allocated_capacity.setter
    def allocated_capacity(self, allocated_capacity):
        """Sets the allocated_capacity of this InlineResponse200203ResponseVolumes.


        :param allocated_capacity: The allocated_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._allocated_capacity = allocated_capacity

    @property
    def data_copies_capacity(self):
        """Gets the data_copies_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The data_copies_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._data_copies_capacity

    @data_copies_capacity.setter
    def data_copies_capacity(self, data_copies_capacity):
        """Sets the data_copies_capacity of this InlineResponse200203ResponseVolumes.


        :param data_copies_capacity: The data_copies_capacity of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._data_copies_capacity = data_copies_capacity

    @property
    def access_type(self):
        """Gets the access_type of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The access_type of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this InlineResponse200203ResponseVolumes.


        :param access_type: The access_type of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    @property
    def read_only(self):
        """Gets the read_only of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The read_only of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this InlineResponse200203ResponseVolumes.


        :param read_only: The read_only of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_only = read_only

    @property
    def nfs_export_path(self):
        """Gets the nfs_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The nfs_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_export_path

    @nfs_export_path.setter
    def nfs_export_path(self, nfs_export_path):
        """Sets the nfs_export_path of this InlineResponse200203ResponseVolumes.


        :param nfs_export_path: The nfs_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_export_path = nfs_export_path

    @property
    def smb_export_path(self):
        """Gets the smb_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_export_path

    @smb_export_path.setter
    def smb_export_path(self, smb_export_path):
        """Sets the smb_export_path of this InlineResponse200203ResponseVolumes.


        :param smb_export_path: The smb_export_path of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_export_path = smb_export_path

    @property
    def mount_sync(self):
        """Gets the mount_sync of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The mount_sync of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._mount_sync

    @mount_sync.setter
    def mount_sync(self, mount_sync):
        """Sets the mount_sync of this InlineResponse200203ResponseVolumes.


        :param mount_sync: The mount_sync of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._mount_sync = mount_sync

    @property
    def atime_update(self):
        """Gets the atime_update of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The atime_update of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._atime_update

    @atime_update.setter
    def atime_update(self, atime_update):
        """Sets the atime_update of this InlineResponse200203ResponseVolumes.


        :param atime_update: The atime_update of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._atime_update = atime_update

    @property
    def ext_metering(self):
        """Gets the ext_metering of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The ext_metering of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._ext_metering

    @ext_metering.setter
    def ext_metering(self, ext_metering):
        """Sets the ext_metering of this InlineResponse200203ResponseVolumes.


        :param ext_metering: The ext_metering of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._ext_metering = ext_metering

    @property
    def images_repo(self):
        """Gets the images_repo of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The images_repo of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._images_repo

    @images_repo.setter
    def images_repo(self, images_repo):
        """Sets the images_repo of this InlineResponse200203ResponseVolumes.


        :param images_repo: The images_repo of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._images_repo = images_repo

    @property
    def nfs_root_squash(self):
        """Gets the nfs_root_squash of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The nfs_root_squash of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_root_squash

    @nfs_root_squash.setter
    def nfs_root_squash(self, nfs_root_squash):
        """Sets the nfs_root_squash of this InlineResponse200203ResponseVolumes.


        :param nfs_root_squash: The nfs_root_squash of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_root_squash = nfs_root_squash

    @property
    def smb_only(self):
        """Gets the smb_only of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_only of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_only

    @smb_only.setter
    def smb_only(self, smb_only):
        """Sets the smb_only of this InlineResponse200203ResponseVolumes.


        :param smb_only: The smb_only of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_only = smb_only

    @property
    def smb_guest(self):
        """Gets the smb_guest of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_guest of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_guest

    @smb_guest.setter
    def smb_guest(self, smb_guest):
        """Sets the smb_guest of this InlineResponse200203ResponseVolumes.


        :param smb_guest: The smb_guest of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_guest = smb_guest

    @property
    def smb_windows_acl(self):
        """Gets the smb_windows_acl of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_windows_acl of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_windows_acl

    @smb_windows_acl.setter
    def smb_windows_acl(self, smb_windows_acl):
        """Sets the smb_windows_acl of this InlineResponse200203ResponseVolumes.


        :param smb_windows_acl: The smb_windows_acl of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_windows_acl = smb_windows_acl

    @property
    def smb_map_archive(self):
        """Gets the smb_map_archive of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_map_archive of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_map_archive

    @smb_map_archive.setter
    def smb_map_archive(self, smb_map_archive):
        """Sets the smb_map_archive of this InlineResponse200203ResponseVolumes.


        :param smb_map_archive: The smb_map_archive of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_map_archive = smb_map_archive

    @property
    def smb_file_create_mask(self):
        """Gets the smb_file_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_file_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_file_create_mask

    @smb_file_create_mask.setter
    def smb_file_create_mask(self, smb_file_create_mask):
        """Sets the smb_file_create_mask of this InlineResponse200203ResponseVolumes.


        :param smb_file_create_mask: The smb_file_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_file_create_mask = smb_file_create_mask

    @property
    def smb_dir_create_mask(self):
        """Gets the smb_dir_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_dir_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_dir_create_mask

    @smb_dir_create_mask.setter
    def smb_dir_create_mask(self, smb_dir_create_mask):
        """Sets the smb_dir_create_mask of this InlineResponse200203ResponseVolumes.


        :param smb_dir_create_mask: The smb_dir_create_mask of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_dir_create_mask = smb_dir_create_mask

    @property
    def smb_aio_size(self):
        """Gets the smb_aio_size of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_aio_size of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._smb_aio_size

    @smb_aio_size.setter
    def smb_aio_size(self, smb_aio_size):
        """Sets the smb_aio_size of this InlineResponse200203ResponseVolumes.


        :param smb_aio_size: The smb_aio_size of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._smb_aio_size = smb_aio_size

    @property
    def smb_browseable(self):
        """Gets the smb_browseable of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_browseable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_browseable

    @smb_browseable.setter
    def smb_browseable(self, smb_browseable):
        """Sets the smb_browseable of this InlineResponse200203ResponseVolumes.


        :param smb_browseable: The smb_browseable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_browseable = smb_browseable

    @property
    def smb_hidden_files(self):
        """Gets the smb_hidden_files of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_hidden_files of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hidden_files

    @smb_hidden_files.setter
    def smb_hidden_files(self, smb_hidden_files):
        """Sets the smb_hidden_files of this InlineResponse200203ResponseVolumes.


        :param smb_hidden_files: The smb_hidden_files of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hidden_files = smb_hidden_files

    @property
    def smb_encryption_mode(self):
        """Gets the smb_encryption_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_encryption_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_encryption_mode

    @smb_encryption_mode.setter
    def smb_encryption_mode(self, smb_encryption_mode):
        """Sets the smb_encryption_mode of this InlineResponse200203ResponseVolumes.


        :param smb_encryption_mode: The smb_encryption_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_encryption_mode = smb_encryption_mode

    @property
    def smb_hide_unreadable(self):
        """Gets the smb_hide_unreadable of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_hide_unreadable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_unreadable

    @smb_hide_unreadable.setter
    def smb_hide_unreadable(self, smb_hide_unreadable):
        """Sets the smb_hide_unreadable of this InlineResponse200203ResponseVolumes.


        :param smb_hide_unreadable: The smb_hide_unreadable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_unreadable = smb_hide_unreadable

    @property
    def smb_hide_unwriteable(self):
        """Gets the smb_hide_unwriteable of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_hide_unwriteable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_unwriteable

    @smb_hide_unwriteable.setter
    def smb_hide_unwriteable(self, smb_hide_unwriteable):
        """Sets the smb_hide_unwriteable of this InlineResponse200203ResponseVolumes.


        :param smb_hide_unwriteable: The smb_hide_unwriteable of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_unwriteable = smb_hide_unwriteable

    @property
    def smb_hide_dot_files(self):
        """Gets the smb_hide_dot_files of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_hide_dot_files of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_dot_files

    @smb_hide_dot_files.setter
    def smb_hide_dot_files(self, smb_hide_dot_files):
        """Sets the smb_hide_dot_files of this InlineResponse200203ResponseVolumes.


        :param smb_hide_dot_files: The smb_hide_dot_files of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_dot_files = smb_hide_dot_files

    @property
    def smb_store_dos_attributes(self):
        """Gets the smb_store_dos_attributes of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The smb_store_dos_attributes of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_store_dos_attributes

    @smb_store_dos_attributes.setter
    def smb_store_dos_attributes(self, smb_store_dos_attributes):
        """Sets the smb_store_dos_attributes of this InlineResponse200203ResponseVolumes.


        :param smb_store_dos_attributes: The smb_store_dos_attributes of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_store_dos_attributes = smb_store_dos_attributes

    @property
    def capacity_history(self):
        """Gets the capacity_history of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The capacity_history of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._capacity_history

    @capacity_history.setter
    def capacity_history(self, capacity_history):
        """Sets the capacity_history of this InlineResponse200203ResponseVolumes.


        :param capacity_history: The capacity_history of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._capacity_history = capacity_history

    @property
    def alert_mode(self):
        """Gets the alert_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The alert_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._alert_mode

    @alert_mode.setter
    def alert_mode(self, alert_mode):
        """Sets the alert_mode of this InlineResponse200203ResponseVolumes.


        :param alert_mode: The alert_mode of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._alert_mode = alert_mode

    @property
    def uquota_state(self):
        """Gets the uquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The uquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._uquota_state

    @uquota_state.setter
    def uquota_state(self, uquota_state):
        """Sets the uquota_state of this InlineResponse200203ResponseVolumes.


        :param uquota_state: The uquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._uquota_state = uquota_state

    @property
    def gquota_state(self):
        """Gets the gquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The gquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._gquota_state

    @gquota_state.setter
    def gquota_state(self, gquota_state):
        """Sets the gquota_state of this InlineResponse200203ResponseVolumes.


        :param gquota_state: The gquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._gquota_state = gquota_state

    @property
    def pquota_state(self):
        """Gets the pquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The pquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pquota_state

    @pquota_state.setter
    def pquota_state(self, pquota_state):
        """Sets the pquota_state of this InlineResponse200203ResponseVolumes.


        :param pquota_state: The pquota_state of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pquota_state = pquota_state

    @property
    def target(self):
        """Gets the target of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The target of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse200203ResponseVolumes.


        :param target: The target of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def lun(self):
        """Gets the lun of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The lun of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this InlineResponse200203ResponseVolumes.


        :param lun: The lun of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._lun = lun

    @property
    def cache(self):
        """Gets the cache of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The cache of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse200203ResponseVolumes.


        :param cache: The cache of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def tenant_id(self):
        """Gets the tenant_id of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The tenant_id of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this InlineResponse200203ResponseVolumes.


        :param tenant_id: The tenant_id of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._tenant_id = tenant_id

    @property
    def has_mirror(self):
        """Gets the has_mirror of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The has_mirror of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_mirror

    @has_mirror.setter
    def has_mirror(self, has_mirror):
        """Sets the has_mirror of this InlineResponse200203ResponseVolumes.


        :param has_mirror: The has_mirror of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_mirror = has_mirror

    @property
    def has_backup(self):
        """Gets the has_backup of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The has_backup of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_backup

    @has_backup.setter
    def has_backup(self, has_backup):
        """Sets the has_backup of this InlineResponse200203ResponseVolumes.


        :param has_backup: The has_backup of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_backup = has_backup

    @property
    def has_snapshots(self):
        """Gets the has_snapshots of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The has_snapshots of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_snapshots

    @has_snapshots.setter
    def has_snapshots(self, has_snapshots):
        """Sets the has_snapshots of this InlineResponse200203ResponseVolumes.


        :param has_snapshots: The has_snapshots of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_snapshots = has_snapshots

    @property
    def shadow_copy_enabled(self):
        """Gets the shadow_copy_enabled of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The shadow_copy_enabled of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._shadow_copy_enabled

    @shadow_copy_enabled.setter
    def shadow_copy_enabled(self, shadow_copy_enabled):
        """Sets the shadow_copy_enabled of this InlineResponse200203ResponseVolumes.


        :param shadow_copy_enabled: The shadow_copy_enabled of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._shadow_copy_enabled = shadow_copy_enabled

    @property
    def is_shadow_copy_clone(self):
        """Gets the is_shadow_copy_clone of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The is_shadow_copy_clone of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._is_shadow_copy_clone

    @is_shadow_copy_clone.setter
    def is_shadow_copy_clone(self, is_shadow_copy_clone):
        """Sets the is_shadow_copy_clone of this InlineResponse200203ResponseVolumes.


        :param is_shadow_copy_clone: The is_shadow_copy_clone of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._is_shadow_copy_clone = is_shadow_copy_clone

    @property
    def read_iops_limit(self):
        """Gets the read_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The read_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_iops_limit

    @read_iops_limit.setter
    def read_iops_limit(self, read_iops_limit):
        """Sets the read_iops_limit of this InlineResponse200203ResponseVolumes.


        :param read_iops_limit: The read_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_iops_limit = read_iops_limit

    @property
    def read_mbps_limit(self):
        """Gets the read_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The read_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_mbps_limit

    @read_mbps_limit.setter
    def read_mbps_limit(self, read_mbps_limit):
        """Sets the read_mbps_limit of this InlineResponse200203ResponseVolumes.


        :param read_mbps_limit: The read_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_mbps_limit = read_mbps_limit

    @property
    def write_iops_limit(self):
        """Gets the write_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The write_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_iops_limit

    @write_iops_limit.setter
    def write_iops_limit(self, write_iops_limit):
        """Sets the write_iops_limit of this InlineResponse200203ResponseVolumes.


        :param write_iops_limit: The write_iops_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_iops_limit = write_iops_limit

    @property
    def write_mbps_limit(self):
        """Gets the write_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The write_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_mbps_limit

    @write_mbps_limit.setter
    def write_mbps_limit(self, write_mbps_limit):
        """Sets the write_mbps_limit of this InlineResponse200203ResponseVolumes.


        :param write_mbps_limit: The write_mbps_limit of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_mbps_limit = write_mbps_limit

    @property
    def thresholds(self):
        """Gets the thresholds of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The thresholds of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._thresholds

    @thresholds.setter
    def thresholds(self, thresholds):
        """Sets the thresholds of this InlineResponse200203ResponseVolumes.


        :param thresholds: The thresholds of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._thresholds = thresholds

    @property
    def comment(self):
        """Gets the comment of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The comment of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse200203ResponseVolumes.


        :param comment: The comment of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The created_at of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200203ResponseVolumes.


        :param created_at: The created_at of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200203ResponseVolumes.  # noqa: E501


        :return: The modified_at of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200203ResponseVolumes.


        :param modified_at: The modified_at of this InlineResponse200203ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200203ResponseVolumes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200203ResponseVolumes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200203ResponseVolumes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20035Logs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'time': 'str',
        'severity': 'str',
        'source_type': 'str',
        'source_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'time': 'time',
        'severity': 'severity',
        'source_type': 'source_type',
        'source_name': 'source_name'
    }

    def __init__(self, id=None, title=None, time=None, severity=None, source_type=None, source_name=None, _configuration=None):  # noqa: E501
        """InlineResponse20035Logs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._title = None
        self._time = None
        self._severity = None
        self._source_type = None
        self._source_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if time is not None:
            self.time = time
        if severity is not None:
            self.severity = severity
        if source_type is not None:
            self.source_type = source_type
        if source_name is not None:
            self.source_name = source_name

    @property
    def id(self):
        """Gets the id of this InlineResponse20035Logs.  # noqa: E501


        :return: The id of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20035Logs.


        :param id: The id of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this InlineResponse20035Logs.  # noqa: E501


        :return: The title of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this InlineResponse20035Logs.


        :param title: The title of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def time(self):
        """Gets the time of this InlineResponse20035Logs.  # noqa: E501


        :return: The time of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InlineResponse20035Logs.


        :param time: The time of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def severity(self):
        """Gets the severity of this InlineResponse20035Logs.  # noqa: E501


        :return: The severity of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this InlineResponse20035Logs.


        :param severity: The severity of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def source_type(self):
        """Gets the source_type of this InlineResponse20035Logs.  # noqa: E501


        :return: The source_type of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this InlineResponse20035Logs.


        :param source_type: The source_type of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._source_type = source_type

    @property
    def source_name(self):
        """Gets the source_name of this InlineResponse20035Logs.  # noqa: E501


        :return: The source_name of this InlineResponse20035Logs.  # noqa: E501
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this InlineResponse20035Logs.


        :param source_name: The source_name of this InlineResponse20035Logs.  # noqa: E501
        :type: str
        """

        self._source_name = source_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20035Logs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20035Logs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20035Logs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20043ResponseUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_name': 'str',
        'update_time': 'str',
        'name': 'str',
        'links': 'str',
        's3_secret_key': 'str',
        'enabled': 'str',
        'account_id': 'str',
        'domain_id': 'str',
        'create_time': 'str',
        's3_access_key': 'str',
        'init_password_changed': 'str',
        'role_list': 'list[str]',
        'project_id': 'str',
        'is_system_user': 'str',
        'id': 'str',
        'password_expires_at': 'str',
        'notify_on_events': 'bool',
        'notification_severity': 'int',
        'primary': 'bool',
        'email': 'str'
    }

    attribute_map = {
        'account_name': 'account_name',
        'update_time': 'update_time',
        'name': 'name',
        'links': 'links',
        's3_secret_key': 's3_secret_key',
        'enabled': 'enabled',
        'account_id': 'account_id',
        'domain_id': 'domain_id',
        'create_time': 'create_time',
        's3_access_key': 's3_access_key',
        'init_password_changed': 'init_password_changed',
        'role_list': 'role_list',
        'project_id': 'project_id',
        'is_system_user': 'is_system_user',
        'id': 'id',
        'password_expires_at': 'password_expires_at',
        'notify_on_events': 'notify_on_events',
        'notification_severity': 'notification_severity',
        'primary': 'primary',
        'email': 'email'
    }

    def __init__(self, account_name=None, update_time=None, name=None, links=None, s3_secret_key=None, enabled=None, account_id=None, domain_id=None, create_time=None, s3_access_key=None, init_password_changed=None, role_list=None, project_id=None, is_system_user=None, id=None, password_expires_at=None, notify_on_events=None, notification_severity=None, primary=None, email=None, _configuration=None):  # noqa: E501
        """InlineResponse20043ResponseUser - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_name = None
        self._update_time = None
        self._name = None
        self._links = None
        self._s3_secret_key = None
        self._enabled = None
        self._account_id = None
        self._domain_id = None
        self._create_time = None
        self._s3_access_key = None
        self._init_password_changed = None
        self._role_list = None
        self._project_id = None
        self._is_system_user = None
        self._id = None
        self._password_expires_at = None
        self._notify_on_events = None
        self._notification_severity = None
        self._primary = None
        self._email = None
        self.discriminator = None

        if account_name is not None:
            self.account_name = account_name
        if update_time is not None:
            self.update_time = update_time
        if name is not None:
            self.name = name
        if links is not None:
            self.links = links
        if s3_secret_key is not None:
            self.s3_secret_key = s3_secret_key
        if enabled is not None:
            self.enabled = enabled
        if account_id is not None:
            self.account_id = account_id
        if domain_id is not None:
            self.domain_id = domain_id
        if create_time is not None:
            self.create_time = create_time
        if s3_access_key is not None:
            self.s3_access_key = s3_access_key
        if init_password_changed is not None:
            self.init_password_changed = init_password_changed
        if role_list is not None:
            self.role_list = role_list
        if project_id is not None:
            self.project_id = project_id
        if is_system_user is not None:
            self.is_system_user = is_system_user
        if id is not None:
            self.id = id
        if password_expires_at is not None:
            self.password_expires_at = password_expires_at
        if notify_on_events is not None:
            self.notify_on_events = notify_on_events
        if notification_severity is not None:
            self.notification_severity = notification_severity
        if primary is not None:
            self.primary = primary
        if email is not None:
            self.email = email

    @property
    def account_name(self):
        """Gets the account_name of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The account_name of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this InlineResponse20043ResponseUser.


        :param account_name: The account_name of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def update_time(self):
        """Gets the update_time of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The update_time of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this InlineResponse20043ResponseUser.


        :param update_time: The update_time of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def name(self):
        """Gets the name of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The name of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20043ResponseUser.


        :param name: The name of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def links(self):
        """Gets the links of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The links of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this InlineResponse20043ResponseUser.


        :param links: The links of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._links = links

    @property
    def s3_secret_key(self):
        """Gets the s3_secret_key of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The s3_secret_key of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._s3_secret_key

    @s3_secret_key.setter
    def s3_secret_key(self, s3_secret_key):
        """Sets the s3_secret_key of this InlineResponse20043ResponseUser.


        :param s3_secret_key: The s3_secret_key of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._s3_secret_key = s3_secret_key

    @property
    def enabled(self):
        """Gets the enabled of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The enabled of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this InlineResponse20043ResponseUser.


        :param enabled: The enabled of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def account_id(self):
        """Gets the account_id of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The account_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this InlineResponse20043ResponseUser.


        :param account_id: The account_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def domain_id(self):
        """Gets the domain_id of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The domain_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this InlineResponse20043ResponseUser.


        :param domain_id: The domain_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    @property
    def create_time(self):
        """Gets the create_time of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The create_time of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this InlineResponse20043ResponseUser.


        :param create_time: The create_time of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def s3_access_key(self):
        """Gets the s3_access_key of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The s3_access_key of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._s3_access_key

    @s3_access_key.setter
    def s3_access_key(self, s3_access_key):
        """Sets the s3_access_key of this InlineResponse20043ResponseUser.


        :param s3_access_key: The s3_access_key of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._s3_access_key = s3_access_key

    @property
    def init_password_changed(self):
        """Gets the init_password_changed of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The init_password_changed of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._init_password_changed

    @init_password_changed.setter
    def init_password_changed(self, init_password_changed):
        """Sets the init_password_changed of this InlineResponse20043ResponseUser.


        :param init_password_changed: The init_password_changed of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._init_password_changed = init_password_changed

    @property
    def role_list(self):
        """Gets the role_list of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The role_list of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_list

    @role_list.setter
    def role_list(self, role_list):
        """Sets the role_list of this InlineResponse20043ResponseUser.


        :param role_list: The role_list of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: list[str]
        """

        self._role_list = role_list

    @property
    def project_id(self):
        """Gets the project_id of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The project_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this InlineResponse20043ResponseUser.


        :param project_id: The project_id of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def is_system_user(self):
        """Gets the is_system_user of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The is_system_user of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._is_system_user

    @is_system_user.setter
    def is_system_user(self, is_system_user):
        """Sets the is_system_user of this InlineResponse20043ResponseUser.


        :param is_system_user: The is_system_user of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._is_system_user = is_system_user

    @property
    def id(self):
        """Gets the id of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The id of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20043ResponseUser.


        :param id: The id of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def password_expires_at(self):
        """Gets the password_expires_at of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The password_expires_at of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._password_expires_at

    @password_expires_at.setter
    def password_expires_at(self, password_expires_at):
        """Sets the password_expires_at of this InlineResponse20043ResponseUser.


        :param password_expires_at: The password_expires_at of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._password_expires_at = password_expires_at

    @property
    def notify_on_events(self):
        """Gets the notify_on_events of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The notify_on_events of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: bool
        """
        return self._notify_on_events

    @notify_on_events.setter
    def notify_on_events(self, notify_on_events):
        """Sets the notify_on_events of this InlineResponse20043ResponseUser.


        :param notify_on_events: The notify_on_events of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: bool
        """

        self._notify_on_events = notify_on_events

    @property
    def notification_severity(self):
        """Gets the notification_severity of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The notification_severity of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: int
        """
        return self._notification_severity

    @notification_severity.setter
    def notification_severity(self, notification_severity):
        """Sets the notification_severity of this InlineResponse20043ResponseUser.


        :param notification_severity: The notification_severity of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: int
        """

        self._notification_severity = notification_severity

    @property
    def primary(self):
        """Gets the primary of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The primary of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this InlineResponse20043ResponseUser.


        :param primary: The primary of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: bool
        """

        self._primary = primary

    @property
    def email(self):
        """Gets the email of this InlineResponse20043ResponseUser.  # noqa: E501


        :return: The email of this InlineResponse20043ResponseUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this InlineResponse20043ResponseUser.


        :param email: The email of this InlineResponse20043ResponseUser.  # noqa: E501
        :type: str
        """

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20043ResponseUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20043ResponseUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20043ResponseUser):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.cloud_settings_api import CloudSettingsApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCloudSettingsApi(unittest.TestCase):
    """CloudSettingsApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.cloud_settings_api.CloudSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_cloud_control_ip_whitelisting_entries(self):
        """Test case for add_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_create_endpoint(self):
        """Test case for create_endpoint

        """
        pass

    def test_create_endpoints_config(self):
        """Test case for create_endpoints_config

        """
        pass

    def test_delete_cloud_control_ip_whitelisting_entries(self):
        """Test case for delete_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_delete_endpoint(self):
        """Test case for delete_endpoint

        """
        pass

    def test_delete_endpoints_config(self):
        """Test case for delete_endpoints_config

        """
        pass

    def test_delete_ticket_settings(self):
        """Test case for delete_ticket_settings

        """
        pass

    def test_disable_cloud_control_ip_whitelisting(self):
        """Test case for disable_cloud_control_ip_whitelisting

        """
        pass

    def test_enable_cloud_control_ip_whitelisting(self):
        """Test case for enable_cloud_control_ip_whitelisting

        """
        pass

    def test_get_cloud_control_ip_whitelist_entries(self):
        """Test case for get_cloud_control_ip_whitelist_entries

        """
        pass

    def test_get_cloud_control_ip_whitelist_status(self):
        """Test case for get_cloud_control_ip_whitelist_status

        """
        pass

    def test_get_cloud_settings(self):
        """Test case for get_cloud_settings

        """
        pass

    def test_get_endpoints(self):
        """Test case for get_endpoints

        """
        pass

    def test_get_endpoints_config(self):
        """Test case for get_endpoints_config

        """
        pass

    def test_get_log_level(self):
        """Test case for get_log_level

        """
        pass

    def test_get_remote_support_access(self):
        """Test case for get_remote_support_access

        """
        pass

    def test_get_tickets_settings(self):
        """Test case for get_tickets_settings

        """
        pass

    def test_set_automatic_drive_replacement(self):
        """Test case for set_automatic_drive_replacement

        """
        pass

    def test_set_ccvm_cert(self):
        """Test case for set_ccvm_cert

        """
        pass

    def test_set_ccvm_default_engine(self):
        """Test case for set_ccvm_default_engine

        """
        pass

    def test_set_mount_capacity_alert_threshold(self):
        """Test case for set_mount_capacity_alert_threshold

        """
        pass

    def test_set_remote_region_backend_protocol(self):
        """Test case for set_remote_region_backend_protocol

        """
        pass

    def test_set_remote_support_access(self):
        """Test case for set_remote_support_access

        """
        pass

    def test_set_snmp(self):
        """Test case for set_snmp

        """
        pass

    def test_set_ticket_settings(self):
        """Test case for set_ticket_settings

        """
        pass

    def test_set_vpsa_cert(self):
        """Test case for set_vpsa_cert

        """
        pass

    def test_set_vpsa_recycle_bin(self):
        """Test case for set_vpsa_recycle_bin

        """
        pass

    def test_set_zadara_cert(self):
        """Test case for set_zadara_cert

        """
        pass

    def test_update_cloud_control_ip_whitelisting_entries(self):
        """Test case for update_cloud_control_ip_whitelisting_entries

        """
        pass

    def test_update_endpoint(self):
        """Test case for update_endpoint

        """
        pass

    def test_update_endpoints_config(self):
        """Test case for update_endpoints_config

        """
        pass


if __name__ == '__main__':
    unittest.main()
